c**********************************************************************
c IO_INIT_TH.F
c**********************************************************************
c Read in thermal data, precompute thermal parameters for getacch subroutine
c
c Input:
c  infile	name of the thermal data input file
c  ntp		number of test particles
c
c Output:
c  in common block /yarko/
c  lambda0(NTPMAX)	precomputed thermal parameters
c  Tstar40(NTPMAX)	
c  rho0(NTPMAX)		
c  psi(NTPMAX)		precomputed complex parameter
c  k_seasonal		number of iterations
c
c  in common block /prdrag/
c  pr(NTPMAX)		precomputed parameter of P-R drag
c
c  in common block /radii/
c  radius(NTPMAX)	radii of TP's, only for io_init_yarko.f subroutine
c
c Remarks: 
c Author: Miroslav Broz, miroslav.broz@email.cz
c Date: Feb 12th 2002

      subroutine io_init_th(infile,ntp)

      include 'swift.inc'
      include 'const.inc'
      include 'yarko.inc'
      include 'pr.inc'

c  input
      character*(*) infile
      integer ntp

c  radii of TP's for io_init_yarko subroutine
      real*8 radius(NTPMAX)
      common/radii/radius

c  internal
      integer i,ierr,ntpchk
      real*8 R,rho,rho_surface,K,C,A,epsilon,T
      real*8 mass,Gama,ls,Rdash,omega,theta
      complex*8 sinz,cosz,z

c  main
      write(*,*) 'Thermal data file called ',infile
      call io_open(7,infile,'old','formatted',ierr)

      read(7,*,err=99,end=99) ntpchk
      if(ntp.eq.0) ntp = ntpchk
      if(ntpchk.ne.ntp) then
        write(*,*) ' SWIFT ERROR: in io_init_th'
        write(*,*) '     Number of test particles differs in ',infile
        call util_exit(1)
      endif
 
      do i=1,ntpchk
        read(7,*,err=99,end=99) R,rho,rho_surface,K,C,A,epsilon,T
c
c  precompute parameters for getacch_yarko subroutine
c  calculation of omega, if not given
c  omega = 1/R, 1 km sized asteroid has the rotational period 5 h
c
        if (T.le.0) then
          omega = TWOPI/(5*3600.)/(2*R/1000)
        else
          omega = TWOPI/(T*3600.)
        endif
c        write(*,*) 'omega = ',omega
        mass=4./3.*pi*R**3*rho
        Gama=sqrt(rho_surface*C*K)
        ls=sqrt(K/(rho_surface*C*omega))
        Rdash=R/ls
        Rdash0(i)=R/sqrt(K/(rho_surface*C))
        z=1/sqrt(2.)*(1.,-1.)*Rdash
c  canceled factor exp(-imag(z)) in fraction psi(i) to avoid numerical problems
        sinz=(cos(dble(z))+(0.,1.)*sin(dble(z))
     &    -(cos(-dble(z))+(0.,1.)*sin(-dble(z)))*exp(2.*imag(z)))
     &    /(0.,2.)
        cosz=(cos(dble(z))+(0.,1.)*sin(dble(z))
     &    +(cos(-dble(z))+(0.,1.)*sin(-dble(z)))*exp(2.*imag(z)))
     &    /2.
        psi(i)=((z**2-3.)*sinz+3.*z*cosz)/(sinz-z*cosz)
        lambda0(i)=Gama*sqrt(omega)/(epsilon*sigma*sqrt(2.)*Rdash)
        theta = sqrt(2.)*Rdash*lambda0(i)
        lambdas0(i)=Gama/(epsilon*sigma*sqrt(2.))
        Tstar40(i)=(1.-A)*S0/(epsilon*sigma)
        rho0(i)=-4./9.*epsilon*sigma*pi*R**2/(mass*cv)
     &    *day**2/AU
        radius(i)=R
        thetas(i) = Gama/(epsilon*sigma*Tstar40(i)**(3./4.))/
     &    sqrt(day/k_gauss)
c debug code
c        write(*,*) 'K = ',K,' ls = ',
c     &    sqrt(K/rho_surface/C*day/k_gauss),
c     &    'Thetas = ',Gama/(epsilon*sigma*Tstar40(i)**(3./4.))/
c     &    sqrt(day/k_gauss)
        rhos0(i)=pi*(R**2)*S0/(mass*cv)*(1.-A)
c
c  precompute parameters for getacch_prdrag subroutine
c  (this is useful for combined *_mvs2fypr integrator; see also io_init_pr
c  - there is a same line, except units of R and rho are different!)
c
        pr(i) = 3.d0/4.d0* S0/(cv**2*rho*R) *day	! unit conversion !!!
      enddo

      close(unit = 7)
      write(*,*) ' '
      return

99    continue
      write(*,*) 'Error reading file',infile
      stop

      end    ! io_init_th.f
c-----------------------------------------------------------------

